<?php
/*
 * Plugin Name:       Tax Exempt for WooCommerce
 * Plugin URI:        https://woocommerce.com/products/woocommerce-tax-exempt-plugin/
 * Description:       WooCommerce Tax Exempt plugin allows merchants to tax-exempt selected customers and user roles.
 * Version:           1.5.7
 * Author:            Addify
 * Developed By:      Addify
 * Author URI:        https://woocommerce.com/vendor/addify/
 * Support:           https://woocommerce.com/vendor/addify/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Domain Path:       /languages
 * Text Domain:       addify_tax_exempt
 *
 * Woo: 4721661:1640a61aff7cf4fdc566b66103bdb843
 * WC requires at least: 3.0.9
 * WC tested up to: 7.*.*
 *
 */
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

	function afrbp_admin_notice() {

		$afrbp_allowed_tags = array(
			'a'      => array(
				'class' => array(),
				'href'  => array(),
				'rel'   => array(),
				'title' => array(),
			),
			'b'      => array(),

			'div'    => array(
				'class' => array(),
				'title' => array(),
				'style' => array(),
			),
			'p'      => array(
				'class' => array(),
			),
			'strong' => array(),

		);

		// Deactivate the plugin
		deactivate_plugins( __FILE__ );

		$afrbp_woo_check = '<div id="message" class="error">
			<p><strong>Tax Exempt for WooCommerce is inactive.</strong> The <a href="http://wordpress.org/extend/plugins/woocommerce/">WooCommerce plugin</a> must be active for this plugin to work. Please install &amp; activate WooCommerce »</p></div>';
		echo wp_kses( __( $afrbp_woo_check, 'addify_tax_exempt' ), $afrbp_allowed_tags );

	}

	add_action( 'admin_notices', 'afrbp_admin_notice' );
}

if ( ! class_exists( 'Addify_Tax_Exempt' ) ) {

	class Addify_Tax_Exempt {

		public function __construct() {

			$this->aftax_global_constents_vars();
			$this->set_media_path_url();
			add_action( 'wp_loaded', array( $this, 'aftax_init' ) );

			register_activation_hook( __FILE__, array( $this, 'aftax_installation' ) );

			if ( is_admin() ) {
				include_once AFTAX_PLUGIN_DIR . 'class_aftax_admin.php';
			} else {
				include_once AFTAX_PLUGIN_DIR . 'class-aftax-front.php';
			}
		}

		private function set_media_path_url() {

			$upload_dir = wp_upload_dir();

			$upload_path = $upload_dir['basedir'] . '/addify-tax-exempt/';

			if ( !is_dir( $upload_path ) ) {
				mkdir( $upload_path );
			}

			$upload_url = $upload_dir['baseurl'] . '/addify-tax-exempt/';

			if ( ! defined( 'AFTAX_MEDIA_URL' ) ) {
				define( 'AFTAX_MEDIA_URL', $upload_url);
			}

			if ( ! defined( 'AFTAX_MEDIA_PATH' ) ) {
				define( 'AFTAX_MEDIA_PATH', $upload_path);
			}
		}

		public function aftax_installation() {

			update_option('af_tax_flush_rules', 'yes' );
		}

		public function aftax_global_constents_vars() {

			if ( ! defined( 'AFTAX_URL' ) ) {
				define( 'AFTAX_URL', plugin_dir_url( __FILE__ ) );
			}

			if ( ! defined( 'AFTAX_BASENAME' ) ) {
				define( 'AFTAX_BASENAME', plugin_basename( __FILE__ ) );
			}

			if ( ! defined( 'AFTAX_PLUGIN_DIR' ) ) {
				define( 'AFTAX_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
			}
		}

		public function aftax_init() {

			if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain( 'addify_tax_exempt', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
			}
		}
	}

	new Addify_Tax_Exempt();

}
